Welcome to mosaik’s documentation! — mosaik 2.0a1 documentation

# Welcome to mosaik’s documentation!

Contents:

- Quickstart
- Requirements
  - Types of simulators and models
  - Integrating simulators
  - Scenario definition
  - Execution
- Glossary
- API Reference
  - `mosaik` — The ende-user API
  - `mosaik.exceptions` — mosaik specific error types
  - `mosaik.scenario` — Classes related to the scenario creation
  - `mosaik.simmanager` — Management of external processes
  - `mosaik.simulator` — Coordinate and execute simulators
  - `mosaik.util` — Utility classes and functions

## Indices and tables

- Index
- Module Index
- Search Page